==> polymer-resource-pack-extras-0.14.0-rc.2+1.21.9-rc1-sources.jar: eu/pb4/polymer/resourcepack/extras/api/format/item/special/SpecialModel.java <==
package eu.pb4.polymer.resourcepack.extras.api.format.item.special;

import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import eu.pb4.polymer.common.impl.LazyIdMapper;
import java.util.function.Function;
import net.minecraft.class_2960;
import net.minecraft.class_5699;

public interface SpecialModel {
    class_5699.class_10388<class_2960, MapCodec<? extends SpecialModel>> TYPES = new LazyIdMapper<>(m -> {
        m.method_65325(class_2960.method_60656("bed"), BedSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("banner"), BannerSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("conduit"), ConduitSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("chest"), ChestSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("head"), HeadSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("player_head"), PlayerHeadSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("shulker_box"), ShulkerBoxSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("shield"), ShieldSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("trident"), TridentSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("decorated_pot"), DecoratedPotSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("standing_sign"), SignSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("hanging_sign"), HangingSignSpecialModel.CODEC);
    });
    Codec<SpecialModel> CODEC = TYPES.method_65323(class_2960.field_25139).dispatch(SpecialModel::codec, Function.identity());
    MapCodec<? extends SpecialModel> codec();
}

==> polymer-resource-pack-extras-0.14.3+1.21.10-sources.jar: eu/pb4/polymer/resourcepack/extras/api/format/item/special/SpecialModel.java <==
package eu.pb4.polymer.resourcepack.extras.api.format.item.special;

import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import eu.pb4.polymer.common.impl.LazyIdMapper;
import java.util.function.Function;
import net.minecraft.class_2960;
import net.minecraft.class_5699;

public interface SpecialModel {
    class_5699.class_10388<class_2960, MapCodec<? extends SpecialModel>> TYPES = new LazyIdMapper<>(m -> {
        m.method_65325(class_2960.method_60656("bed"), BedSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("banner"), BannerSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("conduit"), ConduitSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("copper_golem_statue"), CopperGolemStatueSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("chest"), ChestSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("head"), HeadSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("player_head"), PlayerHeadSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("shulker_box"), ShulkerBoxSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("shield"), ShieldSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("trident"), TridentSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("decorated_pot"), DecoratedPotSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("standing_sign"), SignSpecialModel.CODEC);
        m.method_65325(class_2960.method_60656("hanging_sign"), HangingSignSpecialModel.CODEC);
    });
    Codec<SpecialModel> CODEC = TYPES.method_65323(class_2960.field_25139).dispatch(SpecialModel::codec, Function.identity());
    MapCodec<? extends SpecialModel> codec();
}
